@@ -1,4 +1,4 @@
-from collections import Mapping
+from collections.abc import Mapping
 import re
 
 _HTML = '''
